==> nomachine-7.10.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXSessionManager.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXSessionManager::BEGIN{package NXSessionManager;no warnings;require 
NXSession2;do{"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x32"->import};}package 
NXSessionManager;no warnings;($sessionCloseStarted=(0x0e4d+ 1737-0x1516));sub 
listConnectedSessions{(my (@param)=@_);($sessionId=$param[(0x06d3+ 2442-0x105c)]
);($sessionId=~ s/^.*=// );if (($sessionId=~ /(\w{32})$/ )){if ((not (
NXSession2::existSession ($sessionId)))){NXMsg::error (
"\x65\x4e\x6f\x4d\x61\x74\x63\x68\x46\x6f\x72\x53\x65\x73\x73\x69\x6f\x6e",
"\x6d\x61\x69\x6e",$sessionId);return ((0x05c5+ 4212-0x1639));}(my (
@connectedSessions)=NXSession2::listConnectedSessions ($sessionId));
main::nxwrite (main::nxgetSTDOUT (),
"\x0a\x53\x65\x73\x73\x69\x6f\x6e\x73\x49\x64\x0a");main::nxwrite (
main::nxgetSTDOUT (),(("\x2d" x (0x1368+ 4805-0x260d))."\x0a"));my ($sessionId);
foreach my $sessionId (@connectedSessions){($sessionId=sprintf (
"\x25\x2d\x33\x32\x73",$sessionId));main::nxwrite (main::nxgetSTDOUT (),(
$sessionId."\x0a"));}Logger::debug (
"\x52\x65\x70\x6f\x72\x74\x65\x64\x20\x64\x61\x74\x61\x20\x74\x6f\x20\x63\x6c\x69\x65\x6e\x74\x2e"
);main::nxwrite (main::nxgetSTDOUT (),"\x0a");return ((0x00b5+ 2314-0x09be));}
else{if (($sessionId eq (""))){NXMsg::error (
"\x65\x43\x4d\x44\x43\x61\x6e\x6e\x6f\x74\x53\x65\x6c\x65\x63\x74\x53\x65\x73\x73\x69\x6f\x6e\x4d\x69\x73\x73\x69\x6e\x67\x41\x72\x67"
,"\x6d\x61\x69\x6e");}else{NXMsg::error (
"\x65\x4e\x6f\x4d\x61\x74\x63\x68\x46\x6f\x72\x53\x65\x73\x73\x69\x6f\x6e",
"\x6d\x61\x69\x6e",$sessionId);}}return ((0x203f+ 820-0x2373));}sub 
listConnectedSessionUsers{(my (@param)=@_);(my $message=(""));if ((
Server::isClientNxwebclient ()or Server::isClientNxclient ())){($sessionId=
$param[(0x0dd6+ 4556-0x1fa2)]);}else{($sessionId=$param[(0x18bc+ 2127-0x210a)]);
}($sessionId=~ s/^.*=// );if (($sessionId=~ /(\w{32})$/ )){if ((not (
NXSession2::existSession ($sessionId)))){NXMsg::error (
"\x65\x4e\x6f\x4d\x61\x74\x63\x68\x46\x6f\x72\x53\x65\x73\x73\x69\x6f\x6e",
"\x6d\x61\x69\x6e",$sessionId);return ((0x04e3+ 790-0x07f9));}(my (
@connectedSessions)=NXSession2::listConnectedSessions ($sessionId));
main::nxwrite (main::nxgetSTDOUT (),
"\x55\x73\x65\x72\x6e\x61\x6d\x65\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x53\x65\x73\x73\x69\x6f\x6e\x20\x49\x44\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x0a"
);main::nxwrite (main::nxgetSTDOUT (),(((("\x2d" x (0x0af7+ 3254-0x178c))."\x20"
).("\x2d" x (0x0d1b+ 5094-0x20e1)))."\x0a"));foreach my $session (
@connectedSessions){($session=sprintf ("\x25\x2d\x33\x32\x73",$session));(my $username
=NXSession2::getUsernameBySessionId ($session));($username=sprintf (
"\x25\x2d\x33\x33\x73",$username));($message=((($username."\x20").$session).
"\x0a"));main::nxwrite (main::nxgetSTDOUT (),$message);}if ((
Server::isClientNxwebclient ()or Server::isClientNxclient ())){Logger::debug (((
"\x52\x65\x70\x6f\x72\x74\x65\x64\x20\x64\x61\x74\x61\x20\x74\x6f\x20\x63\x6c\x69\x65\x6e\x74\x5b"
.$message)."\x5d\x2e"));}}else{if (($sessionId eq (""))){NXMsg::error (
"\x65\x43\x4d\x44\x43\x61\x6e\x6e\x6f\x74\x53\x65\x6c\x65\x63\x74\x53\x65\x73\x73\x69\x6f\x6e\x4d\x69\x73\x73\x69\x6e\x67\x41\x72\x67"
,"\x6d\x61\x69\x6e");}else{NXMsg::error (
"\x65\x4e\x6f\x4d\x61\x74\x63\x68\x46\x6f\x72\x53\x65\x73\x73\x69\x6f\x6e",
"\x6d\x61\x69\x6e",$sessionId);}}return ((0x0d6d+ 1700-0x1411));}sub 
considerSessionReconnect{if (((Common::NXSessionType::isVirtualAttach (
NXSessionParameters::getSessionType ())and NXSessionParameters::isReconnectable 
())and NXSessionParameters::isRestoreSession ())){return ((0x1561+ 1488-0x1b30))
;}else{return ((0x04f6+ 2350-0x0e24));}}sub considerBeforeSessionDisconnect{if (
(Common::NXSessionType::isVirtual (NXSessionParameters::getSessionType ())and (
not (Server::isMasterGoingToShutdown ())))){NXEvent::beforeSessionDisconnect ();
}}sub considerAfterSessionDisconnect{if ((Common::NXSessionType::isVirtual (
NXSessionParameters::getSessionType ())and (not (Server::isMasterGoingToShutdown
 ())))){NXEvent::afterSessionDisconnect ();}}sub considerBeforeSessionStart{if (
(NXSessionParameters::isNotRestoreSession ()and 
NXSessionParameters::isNotFirstAttach ())){NXEvent::beforeSessionStart ();}}sub 
considerBeforeSessionClose{if ((((isNotSessionCloseStarted ()and 
NXSessionParameters::getSessionType ())and Common::NXSessionType::isVirtual (
NXSessionParameters::getSessionType ()))or Common::NXSessionType::isAttach (
NXSessionParameters::getSessionType ()))){if ((
NXSessionParameters::isNotRestoreSession ()and 
NXSessionParameters::isNotFirstAttach ())){NXEvent::beforeSessionClose ();}}}sub
 considerAfterSessionClose{if (((NXSessionParameters::getSessionType ()and 
Common::NXSessionType::isVirtual (NXSessionParameters::getSessionType ()))or 
Common::NXSessionType::isAttach (NXSessionParameters::getSessionType ()))){if ((
NXSessionParameters::isNotRestoreSession ()and 
NXSessionParameters::isNotFirstAttach ())){NXEvent::afterSessionClose ();}}}sub 
considerBeforeSessionFailure{if (((NXSessionParameters::getSessionType ()and 
Common::NXSessionType::isVirtual (NXSessionParameters::getSessionType ()))or 
Common::NXSessionType::isAttach (NXSessionParameters::getSessionType ()))){if ((
NXSessionParameters::isNotRestoreSession ()and 
NXSessionParameters::isNotFirstAttach ())){NXEvent::beforeSessionFailure ();}}}
sub considerAfterSessionFailure{if (((NXSessionParameters::getSessionType ()and 
Common::NXSessionType::isVirtual (NXSessionParameters::getSessionType ()))or 
Common::NXSessionType::isAttach (NXSessionParameters::getSessionType ()))){if ((
NXSessionParameters::isNotRestoreSession ()and 
NXSessionParameters::isNotFirstAttach ())){NXEvent::afterSessionFailure ();}}}
sub setSessionCloseStarted{($NXSession::sessionCloseStarted=
(0x19a3+ 1896-0x210a));}sub isSessionCloseStarted{return (
$NXSession::sessionCloseStarted);}sub isNotSessionCloseStarted{return ((!
isSessionCloseStarted ()));}return ((0x0fd6+ 5257-0x245e));

==> nomachine-8.0.168-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXSessionManager.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXSessionManager::BEGIN{package NXSessionManager;no warnings;require 
NXSession2;do{"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x32"->import};}package 
NXSessionManager;no warnings;($sessionCloseStarted=(0x03ad+ 4780-0x1659));sub 
listConnectedSessions{(my (@param)=@_);($sessionId=$param[(0x03ff+ 539-0x0619)])
;($sessionId=~ s/^.*=// );if (($sessionId=~ /(\w{32})$/ )){if ((not (
NXSession2::existSession ($sessionId)))){NXMsg::error (
"\x65\x4e\x6f\x4d\x61\x74\x63\x68\x46\x6f\x72\x53\x65\x73\x73\x69\x6f\x6e",
"\x6d\x61\x69\x6e",$sessionId);return ((0x0a50+ 360-0x0bb8));}(my (
@connectedSessions)=NXSession2::listConnectedSessions ($sessionId));
main::nxwrite (main::nxgetSTDOUT (),
"\x0a\x53\x65\x73\x73\x69\x6f\x6e\x73\x49\x64\x0a");main::nxwrite (
main::nxgetSTDOUT (),(("\x2d" x (0x0db1+ 4916-0x20c5))."\x0a"));my ($sessionId);
foreach my $sessionId (@connectedSessions){($sessionId=sprintf (
"\x25\x2d\x33\x32\x73",$sessionId));main::nxwrite (main::nxgetSTDOUT (),(
$sessionId."\x0a"));}Logger::debug (
"\x52\x65\x70\x6f\x72\x74\x65\x64\x20\x64\x61\x74\x61\x20\x74\x6f\x20\x63\x6c\x69\x65\x6e\x74\x2e"
);main::nxwrite (main::nxgetSTDOUT (),"\x0a");return ((0x2657+  93-0x26b3));}
else{if (($sessionId eq (""))){NXMsg::error (
"\x65\x43\x4d\x44\x43\x61\x6e\x6e\x6f\x74\x53\x65\x6c\x65\x63\x74\x53\x65\x73\x73\x69\x6f\x6e\x4d\x69\x73\x73\x69\x6e\x67\x41\x72\x67"
,"\x6d\x61\x69\x6e");}else{NXMsg::error (
"\x65\x4e\x6f\x4d\x61\x74\x63\x68\x46\x6f\x72\x53\x65\x73\x73\x69\x6f\x6e",
"\x6d\x61\x69\x6e",$sessionId);}}return ((0x0851+ 5232-0x1cc1));}sub 
listConnectedSessionUsers{(my (@param)=@_);(my $message=(""));if ((
Server::isClientNxwebclient ()or Server::isClientNxclient ())){($sessionId=
$param[(0x0389+ 5677-0x19b6)]);}else{($sessionId=$param[(0x2042+ 1093-0x2486)]);
}($sessionId=~ s/^.*=// );if (($sessionId=~ /(\w{32})$/ )){if ((not (
NXSession2::existSession ($sessionId)))){NXMsg::error (
"\x65\x4e\x6f\x4d\x61\x74\x63\x68\x46\x6f\x72\x53\x65\x73\x73\x69\x6f\x6e",
"\x6d\x61\x69\x6e",$sessionId);return ((0x0555+ 7225-0x218e));}(my (
@connectedSessions)=NXSession2::listConnectedSessions ($sessionId));
main::nxwrite (main::nxgetSTDOUT (),
"\x55\x73\x65\x72\x6e\x61\x6d\x65\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x53\x65\x73\x73\x69\x6f\x6e\x20\x49\x44\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x20\x0a"
);main::nxwrite (main::nxgetSTDOUT (),(((("\x2d" x (0x06f3+ 5438-0x1c10))."\x20"
).("\x2d" x (0x0052+ 2885-0x0b77)))."\x0a"));foreach my $session (
@connectedSessions){($session=sprintf ("\x25\x2d\x33\x32\x73",$session));(my $username
=NXSession2::getUsernameBySessionId ($session));($username=sprintf (
"\x25\x2d\x33\x33\x73",$username));($message=((($username."\x20").$session).
"\x0a"));main::nxwrite (main::nxgetSTDOUT (),$message);}if ((
Server::isClientNxwebclient ()or Server::isClientNxclient ())){Logger::debug (((
"\x52\x65\x70\x6f\x72\x74\x65\x64\x20\x64\x61\x74\x61\x20\x74\x6f\x20\x63\x6c\x69\x65\x6e\x74\x5b"
.$message)."\x5d\x2e"));}}else{if (($sessionId eq (""))){NXMsg::error (
"\x65\x43\x4d\x44\x43\x61\x6e\x6e\x6f\x74\x53\x65\x6c\x65\x63\x74\x53\x65\x73\x73\x69\x6f\x6e\x4d\x69\x73\x73\x69\x6e\x67\x41\x72\x67"
,"\x6d\x61\x69\x6e");}else{NXMsg::error (
"\x65\x4e\x6f\x4d\x61\x74\x63\x68\x46\x6f\x72\x53\x65\x73\x73\x69\x6f\x6e",
"\x6d\x61\x69\x6e",$sessionId);}}return ((0x0dcf+ 5116-0x21cb));}sub 
considerSessionReconnect{if (((Common::NXSessionType::isVirtualAttach (
NXSessionParameters::getSessionType ())and NXSessionParameters::isReconnectable 
())and NXSessionParameters::isRestoreSession ())){return ((0x04cf+ 3132-0x110a))
;}else{return ((0x084a+ 2751-0x1309));}}sub considerBeforeSessionDisconnect{if (
(Common::NXSessionType::isVirtual (NXSessionParameters::getSessionType ())and (
not (Server::isMasterGoingToShutdown ())))){NXEvent::beforeSessionDisconnect ();
}}sub considerAfterSessionDisconnect{if ((Common::NXSessionType::isVirtual (
NXSessionParameters::getSessionType ())and (not (Server::isMasterGoingToShutdown
 ())))){NXEvent::afterSessionDisconnect ();}}sub considerBeforeSessionStart{if (
(NXSessionParameters::isNotRestoreSession ()and 
NXSessionParameters::isNotFirstAttach ())){NXEvent::beforeSessionStart ();}}sub 
considerBeforeSessionClose{if ((((isNotSessionCloseStarted ()and 
NXSessionParameters::getSessionType ())and Common::NXSessionType::isVirtual (
NXSessionParameters::getSessionType ()))or Common::NXSessionType::isAttach (
NXSessionParameters::getSessionType ()))){if ((
NXSessionParameters::isNotRestoreSession ()and 
NXSessionParameters::isNotFirstAttach ())){NXEvent::beforeSessionClose ();}}}sub
 considerAfterSessionClose{if (((NXSessionParameters::getSessionType ()and 
Common::NXSessionType::isVirtual (NXSessionParameters::getSessionType ()))or 
Common::NXSessionType::isAttach (NXSessionParameters::getSessionType ()))){if ((
NXSessionParameters::isNotRestoreSession ()and 
NXSessionParameters::isNotFirstAttach ())){NXEvent::afterSessionClose ();}}}sub 
considerBeforeSessionFailure{if (((NXSessionParameters::getSessionType ()and 
Common::NXSessionType::isVirtual (NXSessionParameters::getSessionType ()))or 
Common::NXSessionType::isAttach (NXSessionParameters::getSessionType ()))){if ((
NXSessionParameters::isNotRestoreSession ()and 
NXSessionParameters::isNotFirstAttach ())){NXEvent::beforeSessionFailure ();}}}
sub considerAfterSessionFailure{if (((NXSessionParameters::getSessionType ()and 
Common::NXSessionType::isVirtual (NXSessionParameters::getSessionType ()))or 
Common::NXSessionType::isAttach (NXSessionParameters::getSessionType ()))){if ((
NXSessionParameters::isNotRestoreSession ()and 
NXSessionParameters::isNotFirstAttach ())){NXEvent::afterSessionFailure ();}}}
sub setSessionCloseStarted{($NXSession::sessionCloseStarted=
(0x0c21+ 1732-0x12e4));}sub isSessionCloseStarted{return (
$NXSession::sessionCloseStarted);}sub isNotSessionCloseStarted{return ((!
isSessionCloseStarted ()));}return ((0x0944+  87-0x099a));
